
Hidden Markov Model
===================

This package is an implementation of Viterbi Algorithm, Forward algorithm and the Baum Welch Algorithm. The computations are done via matrices to improve the algorithm runtime. Package **hidden_markov** is tested with Python version 2.7 and Python version 3.5.

Documentation
-------------

`Check this link <http://hidden-markov.readthedocs.io/en/latest/>`_ for a detailed documentation of the project. 

If you are new to hidden markov models check out this `tutorial <https://drive.google.com/file/d/0B51S7y4fFTS2bnNLcnllc1dpdVE/view?usp=sharing>`_  . 

Requirements
------------

* `numpy <http://www.numpy.org/>`_  

License
-------

Copyright (c) 2016 Rahul Ramesh.  See the LICENSE file for license rights and limitations (MIT).
